package com.playlet.system.service;

import java.util.List;
import com.playlet.system.domain.PlayletPublicDetail;
import com.baomidou.mybatisplus.extension.service.IService;

/**
 * 公众号文章详情Service接口
 *
 * @author ruoyi
 * @date 2024-04-07
 */
public interface IPlayletPublicDetailService extends IService<PlayletPublicDetail>
{
    /**
     * 查询公众号文章详情
     *
     * @param id 公众号文章详情主键
     * @return 公众号文章详情
     */
    public PlayletPublicDetail selectPlayletPublicDetailById(Long id);

    /**
     * 查询公众号文章详情列表
     *
     * @param playletPublicDetail 公众号文章详情
     * @return 公众号文章详情集合
     */
    public List<PlayletPublicDetail> selectPlayletPublicDetailList(PlayletPublicDetail playletPublicDetail);

    /**
     * 新增公众号文章详情
     *
     * @param playletPublicDetail 公众号文章详情
     * @return 结果
     */
    public int insertPlayletPublicDetail(PlayletPublicDetail playletPublicDetail);

    /**
     * 修改公众号文章详情
     *
     * @param playletPublicDetail 公众号文章详情
     * @return 结果
     */
    public int updatePlayletPublicDetail(PlayletPublicDetail playletPublicDetail);

    /**
     * 批量删除公众号文章详情
     *
     * @param ids 需要删除的公众号文章详情主键集合
     * @return 结果
     */
    public int deletePlayletPublicDetailByIds(String ids);

    /**
     * 删除公众号文章详情信息
     *
     * @param id 公众号文章详情主键
     * @return 结果
     */
    public int deletePlayletPublicDetailById(Long id);
}
